package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````W!<``#0```!$P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````%*\`
M`!2O```%`````!````$```#`O0``P,T``,#-``!0`@``E!(```8`````$```
M`@```,B]``#(S0``R,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&24H```E*```)2@``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP+T`
M`,#-``#`S0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`905P*D9SY\040*^,VBXE[M1AS*H1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````.K3[PYNQ=\?SMY'+6M_FGPNQ9NVU&34?"#_Y`ZYC?$.V7%8'.)'Q@&R
M`8MOK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-
MXYX,.I<+6>CM['^IG)OAIP(*H^#[20`````````````````````#`@``````
M```````2````=P(`````````````$@```&("`````````````!(````,`0``
M```````````2````DP``````````````$@````$!`````````````!$```"U
M`@`````````````2````DP$`````````````$@```*`"`````````````!(`
M```B`0`````````````2````$0``````````````(````&@"````````````
M`!(```#6`@`````````````2````!`,`````````````$@```#,"````````
M`````!(```#B`0`````````````2````4P$`````````````$@```+0`````
M`````````!(```!#`0`````````````2````-0$`````````````$@```$@#
M`````````````!(```#W`@`````````````2````[P$`````````````$@``
M`.H!`````````````!(````@```````````````@````L0$`````````````
M$@```!$!`````````````!(```##`@`````````````2````.@,`````````
M````$@```#P``````````````"````#.`@`````````````2````5@``````
M````````$@```(,!`````````````!(```!S```````````````2````\```
M````````````$@```(0``````````````!(````+`P`````````````2````
MX`(`````````````$0```*X"`````````````!(```",`@`````````````2
M````6P(`````````````$@```!H$`````````````!(```#4````````````
M```2````YP(`````````````$@```%P#`````````````!$```!U`0``````
M```````2````4@(`````````````$@```!0"`````````````!(```!G`0``
M```````````2````DP(`````````````$@```*H!`````````````!(````6
M`0`````````````2````9`,`````````````$@```)H"`````````````!(`
M``!;`P`````````````A````A0(`````````````$@```.X"````````````
M`!(````R`P`````````````2````GP``````````````$@```)X!````````
M`````!(````D`P`````````````2````6@,`````````````$0```'`"````
M`````````!(```!*`@`````````````2````VP$`````````````$@```.,`
M`````````````!$```"\`0`````````````1````7`$`````````````$@``
M`&0``````````````!(```!^`@`````````````2````00,`````````````
M$@```!4#`````````````"(```!%`@`````````````2````P@``````````
M````$@```+4#``!$80```````!(`#P`C!```$&```&\````2``X`5`0``,!/
M``"Q#```$@`.`%4#``"@%0``/`(``!(`#@"-`P```$D```4````2``X`P@,`
M`(!<``"&`P``$@`.`',$```020``)0(``!(`#@`^!```G!$````````2``L`
M?`,``!#0````````$``8`)X#``!`2P``*@```!(`#@#8`P``,$X``'8````2
M``X`)`(``%QA```$````$0`0`#P$``"@1P``.P```!(`#@"(`P``5.``````
M```0`!@`800``/!.``#'````$@`.`"\$````T````````!``%P#\`P``<$L`
M`.<````2``X`=0,``!#0````````$``7`(`$```,T```!````!$`%P"K`P``
M(&$```(````2``X`-00``-P7````````$@`.`$0$``#`8```70```!(`#@`Q
M!````-`````````@`!<`NP,``%AA```$````$0`0``@$``"P3@``-````!(`
M#@#F`P``0$@``+D````2``X`B@0``&!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A
M8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T
M<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/
M7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W-T86-K7V-H:U]F86EL`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?
M9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?;&EB8U]C<W5?:6YI=`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXQ+C,`1TQ)0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C```````@`#``,`````````!`````0```````,`!0`#
M``8`!P````````````,`!``"``(```````,`!0`#`````P``````````````
M!0`#``,``P`#``,````#``,````#``(````#``,````(``,``P`#``,``P``
M````!``#``,``P`'`````````````P`#``D``P````$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`&
M`!H"```0````<````',?:0D```D`EP0``!`````4:6D-```(`*,$```0````
M<AEI"0``!@"M!```$````!)I:0T```4`N00``!````!T&6D)```$`,,$```0
M````$&EI#0```P#/!`````````$``@#+`0``$``````````2:6D-```'`+D$
M```0````$&EI#0```@#/!````````,#-```(````Q,T```@```#\SP``"```
M``30```(````#-````@```#,SP``!@8``-#/```&"@``U,\```8+``#8SP``
M!AD``-S/```&'@``X,\```8A``#DSP``!B(``.C/```&)@``[,\```8M``#P
MSP``!D(``/3/```&0P``^,\```9(``#<S@``!P$``.#.```'`@``Y,X```<#
M``#HS@``!P0``.S.```'!0``\,X```<'``#TS@``!P@``/C.```'"0``_,X`
M``<,````SP``!PT```3/```'#@``",\```</```,SP``!Q```!#/```'$0``
M%,\```<2```8SP``!Q,``!S/```'%```(,\```<5```DSP``!Q8``"C/```'
M%P``+,\```<8```PSP``!QH``#3/```'&P``.,\```<<```\SP``!QT``$#/
M```''P``1,\```<@``!(SP``!R,``$S/```')```4,\```<E``!4SP``!R<`
M`%C/```'*```7,\```<I``!@SP``!RH``&3/```'*P``:,\```<L``!LSP``
M!RX``'#/```'+P``=,\```<P``!XSP``!S$``'S/```',@``@,\```<S``"$
MSP``!S0``(C/```'-0``C,\```<V``"0SP``!S@``)3/```'.0``F,\```<Z
M``"<SP``!SL``*#/```'/```I,\```<]``"HSP``!S\``*S/```'0```L,\`
M``=!``"TSP``!T0``+C/```'10``O,\```=&``#`SP``!T<``,3/```'20``
MR,\```=*``!3@^P(Z'L&``"!PRN]``"+@P0!``"%P'0%Z-8#``"#Q`A;PP#_
MLP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````Z=#_
M____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@````
MZ:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*````&@X
M````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C-```
M`&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/____^C
M0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I\/[_
M__^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)````#I
MP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````:*@`
M``#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L````
M:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O___Z-X
M````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0_O__
M_Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$``.G@
M_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H&`$`
M`.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0```!H
M,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____H[``
M``!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]____
MH[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``Z0#]
M____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(`0``
MZ=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW````&B@
M`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^CZ```
M`&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S___^C
M]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,$`0``9I#_HR@!``!F
MD(U,)`2#Y/#_<?Q5B>575E-1B<_H:`(``('#&+D``(/L+(M!!(E%U(M!"(E%
MT&6A%````(E%Y#'`C4704(U%U%!1Z%K___^+@P`!``"#Q`Q04/^S%`$``.B4
M2@``BX,@`0``@\00@#@`#X0B`0``B[/\````@^P,_S;HXOS__X"(_@(```):
M_S;HT_S__X"(_@(```&+!X/$$(/`!3W___\_#X=5`0``@^P,P>`"4.B-_O__
MBW74BP^#Q!")@W01``#'@W@1```$````BQ:#^0&)$(V38)3__XE0!(N3/`$`
M`(E0"(V38Y3__XE0#'X7N@$```"-="8`BSR6B7R0#(/"`3G1=?*#[`S'1(@,
M`````(/!`VH`4(V#$'G__U%0_[.`$0``Z&;[__^#Q""%P(G&#X2M````@^P,
M_[.`$0``C7W@Z%C]__^-@S"3__^)^N@+*@``@\00A<!T;8/L#/^S@!$``.CV
M^O__Z&'\__^#Q!")\(M-Y&4S#10````/A:D```"-9?!96UY?78UA_,/HZ_O_
M_X7`B8.`$0``#X2/````@^P,4.A$_/__B[/\````6?\VZ*;[__^#Q!#&@'$%
M````Z:O^__^+@WP1``"%P'0]@^P,4.B42```@\00Z7C___^#[`S_LX`1``#H
M#OO__X/$$(G&Z3O___]04(V#XI+___^S)`$``%#H(/W__XV#Y9+__XGZZ$,I
M``"%P(F#?!$```^$,?___^NFZ%Y)``"#[`QJ`>B4_?__,>U>B>&#Y/!05%+H
M(@```('#Y+8``(V#4)+__U"-@_"1__]045;_LRP!``#HT_K___2+'"3#9I!F
MD&:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.0```"!PINV``"-BD`!``"-
M@D`!```YR'0=BX((`0``A<!T$U6)Y8/L%%'_T(/$$,G#D(UT)@#SPXVV````
M`.BD````@<);M@``58V*0`$``(V"0`$``"G(B>53P?@"B<.#[`3!ZQ\!V-'X
M=!2+D@P!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7____
M@<,'M@``@^P$@+M0`0```'4GBX,H`0``A<!T$8/L#/^S-`$``.BE_/__@\00
MZ#7____&@U`!```!BUW\R<.)]HV\)P````!5B>5=Z5?___^+%"3#9I"055>-
M:#A64X'L#`,``(U,)'B)1"14B70D$&6+'10```")G"3\`@``,=N)3"0(B7PD
M%(VT)@````"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$``````_*B00D
MB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_``GXB439
M"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(,U4X,T4\
M,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD=<B+7"14
MBU,,BTL<BS.+>P2+0PB)5"0<BU,4B4PD#(M+)(E$)!B+0Q")5"0$BU,8B4PD
M7(E\)!2)!"2)5"0(BU,@BUPD!(E4)%B)\L'F!8G1B?6+="18#ZSY&XM\)`B)
M5"00"<T#="1XB>B)\8MT)`R!P9EY@EH!R(L,)#'>(W0D'#'/BTPD&(ET)"`A
MSXG^BWPD"#'^`?")1"0@BWPD&(ML)!R+!"2+5"0$QT0D)`````")^8G^QT0D
M/``````/K.X"P>$>B<>+1"00B<V+3"0(QT0D+``````)]0.,)(````")UHEL
M)#");"0XQT0D1`````"!P9EY@EHC="04,>\AQXET)"B)_HL\)#'^BWPD)`'Q
MBW0D((G]B?")]\'@!8E$)"B+="0H#ZSO&XML)!0)_HM\)!")\(LT)`'(B40D
M*(GYB?@/K.@"P>$>BWPD!(G-BTPD,`G%`[0DB````!.\)(P```");"1`B?"+
M="0@!9EY@EJ)^HM\)#B#T@`QZ3';(<['1"1,`````,=$)#P`````,?>)_HG?
MBUPD.`'&BT0D*!'7BU0D+(ET)#")?"0TBWPD)(G&QT0D-``````/K-`;P>8%
MBU0D+(G!"?&+="0@B<@#1"0PB?$/K/X"P>$>B40D,(M\)#`)\0.<))````")
M3"1@B4PD2(G8!9EY@EHQS2-L)"@S;"1`B>F+;"0T`<&)^,'@!8E$)""+="0@
M#ZSO&PG^B?`!R#'_B<:+1"0HB<'!X1X/K-`"B<V+5"1`BTPD8`G%`Y0DF```
M`(EL)#B);"1`B=`%F7F"6C'I(TPD,(ML)$B+5"0TQT0D)`````#'1"0T````
M`,=$)$0`````,<V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)"@+;"0HB>B+
M;"1``<B)1"0@BT0D,(G!#ZS0`L'A'HM4)$P)P8M$)$@#A"2@````$Y0DI```
M`(E,)#")3"1(!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)3"0H
MB5PD+,=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;B?$)U8GH`T0D*,'A
M'@^L_@*)S0GUB40D*(EL)$"+7"0X`YPDJ````(MT)#P3M"2L````BTPD2(G8
MB?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$)"@1UXM4)"R)="0XB7PD
M/,=$)#P`````B<8/K-`;P>8%BU0D),=$)"0`````B<$)\8G(`T0D.#'_B<:+
M1"0@B<$/K-`"P>$>BU0D+`G!BT0D,`.$)+````")3"0XB4PD2`69>8):,<TC
M;"0H,VPD0(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D
M((M$)"B)P<'A'@^LT`*)S0G%B6PD,(M4)$`#E"2X````BTPD1!.,)+P```#'
M1"0T`````,=$)$0`````B=`%F7F"6HG*BTPD2(/2`(E$)"@QVXE4)"R+5"0X
M,>DA\3'*B=`#1"0HB=H35"0LB40D*(M$)"")5"0LBU0D),=$)"P`````B<'!
MX06)3"1`B=&)P@^LRAN+3"1`B50D2`M,)$B)R`-$)"B)\0^L_@+!X1X)\8E$
M)"B+1"0X`X0DP````(E,)$")3"1(!9EY@EHQS2-L)"`S;"0PBWPD*(M4)"3'
M1"0\`````,=$)"0`````QT0D-`````")Z8ML)"P!P8GXP>`%B40D.(MT)#@/
MK.\;"?Z)\`'(,?^)QHM$)"")P<'A'@^LT`*)S8M4)#"+3"1("<4#E"3(````
MB6PD.(EL)$B)T(M4)"P%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$)"")
M\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P0^LT`+!X1Z+5"1$"<&+
M1"1``X0DT````!.4)-0```")3"0PB4PD8(ML)$C'1"1$``````69>8):@](`
M,<TQVR'U,VPD.(GI`<&+1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L````
M`,'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-BTPD8`GU
M`YPDV````(MT)#P3M"3<````B40D*(EL)$")V(GRBW0D(`69>8):@](`,>DQ
MVXG?(<XS="0P`<:+1"0H$=>+5"0LB70D.(E\)#S'1"0\`````(G&#ZS0&\'F
M!8M4)"2)P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1X)P8E,)#B+1"0P`X0D
MX````(E,)$B+5"0LQT0D)`````#'1"0T``````69>8):,<TC;"0H,VPD0(GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P<'A
M'@^LT`*)S8M4)$"+3"1$"<4#E"3H````$XPD[````(EL)#")T`69>8):B<J+
M3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)VA-4)"R)1"0HBT0D
M((E4)"R+5"0DB<'!X06)3"1`B=&)P@^LRAN+3"1`BUPD.(E4)$@+3"1(QT0D
M+`````"+5"0DQT0D1`````#'1"0\`````(G(B?$#1"0H#ZS^`L'A'@GQ`YPD
M\````(E$)"B+?"0HB4PD2(E,)$")V`69>8):,<TC;"0@,VPD,(GIBVPD+`'!
MB?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&BT0D((G!P>$>#ZS0`HG-BU0D
M,(M,)$@)Q0.4)/@```");"0XB6PD2(G0!9EY@EHQZ2-,)"B+;"1`,<V)Z0'!
MB?#!X`6)1"0@B?`/K/@;B40D,(ML)"`+;"0PBU0D+,=$)"0`````QT0D-```
M``")Z(ML)$@!R(E$)""+1"0HB<$/K-`"P>$>BU0D1,=$)$0`````"<&+1"1`
M`X0D``$``!.4)`0!``")3"1@B4PD,`69>8):@](`,<TQVR'U,VPD.(GI`<&+
M1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L`````,'A!8E,)$")T8ML)$")
MP@^LRAN+3"1@"=6)\HGH`T0D*,'B'@^L_@*)U0GU`YPD"`$``(E$)"B);"1`
MB6PD8(MT)""+5"0LB=@%F7F"6C'I(<XS="0PB?$!P8M$)"B)Q@^LT!O!Y@6+
M5"0DQT0D)`````")1"0XBVPD.(M$)"`)]0'I,?^+;"1@B<Z)3"1(B<'!X1X/
MK-`"B<N+5"0P"<,#E"00`0``B5PD,(G0BU0D1`69>8):,=TC;"0H,VPD0(M<
M)"R)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)#@+;"0X`>F)3"1@B4PD((M,
M)"B)R,'@'@^LV0*)Q8M$)$`)S0.$)!@!``"+3"0P$Y0D'`$``(EL)#@%H>O9
M;H/2`#'IBVPD2#';QT0D-``````QS8GI`<&+1"0@$=.+5"0DB4PD*(E<)"R)
M\\=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;BTPD*`G5B?(!Z<'B'HG5
MBY0D(`$``(E,)$@/K/L"B4PD*(M,)#`)W8'"H>O9;HM<)"R)T(EL)$"+5"0D
M`<@S;"0XB>F+;"1@,<V+3"0HB>X!QHG(P>`%B40D,(M$)""+;"0P#ZS9&XGS
M"<V)P0'KP>$>#ZS0`HG-BY0D*`$``(E<)#`)Q8M$)#B)7"1@B>^+;"1`@<*A
MZ]ENB7PD.`'0,?V+?"0PB>Z+;"1(,?6)Z8ML)#0!P8GXP>`%B40D((MT)"`/
MK.\;BT0D*(M4)"P)_L=$)"0`````QT0D+``````!\8E,)$B)3"0@B<'!X1X/
MK-`"B<V+C"0P`0``BU0D)`G%BT0D0(GNBVPD.('!H>O9;HET)$`!R#'UB>Z+
M;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)#2)1"0HBVPD*(M$)#`)]0'I,?^)
MSHE,)&")P<'A'@^LT`*)RXN4)#@!```)PXM$)#B)W8E<)#B+7"1`@<*AZ]EN
M`="+5"0D,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0P
MBT0D(`'IB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)$`!``"+C"1$`0``
MBT0D0(ML)#B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';
MB=F+1"0HBYPD2`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````
MP>$%B4PD0(G1BVPD0(G"BT0D.`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQ
MP>$>#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$
M)"")RXG&#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)
MWL=$)"P`````#ZS0`HN4)%`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+
M5"0D,>F+;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D
M(`'IB4PD*(E,)&")P<'A'@^LT`*+E"18`0``B<V+C"1<`0``"<6+1"0XB6PD
M,(ML)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+
M1"0H,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPD
M8`$``(M$)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"1(B4PD((GQP>$>
M#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD8#'UB>D!P8M$)"")
MQ@^LT!O!Y@6+5"0LQT0D+`````")1"1`BVPD0(M$)"@)]0'I,?^)SHE,)&")
MP<'A'@^LT`*)RXN4)&@!```)PXM$)#")W8E<)$"+7"0X@<*AZ]EN`="+5"0D
M,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0PBT0D(`'I
MB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)'`!``"+C"1T`0``BT0D.(ML
M)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';B=F+1"0H
MBYPD>`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````P>$%B4PD
M.(G1BVPD.(G"BT0D0`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQP>$>#ZS^
M`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$)"")RXG&
M#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)WL=$)"P`
M````#ZS0`HN4)(`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+5"0D,>F+
M;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D(`'IB4PD
M*(E,)&")P<'A'@^LT`*+E"2(`0``B<V+C"2,`0``"<6+1"0XB6PD,(ML)$"!
MPJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+1"0H,>H#
M5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPDD`$``(M$
M)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"0@B4PD.(GQP>$>#ZS^`HG-
M"?6!PZ'KV6Z)[XML)#`!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"")Q@^LT!O!
MY@6+5"0LQT0D+`````")1"1(BVPD2(M$)"@)]0'I,?^)SHE,)&")P<'A'@^L
MT`*+E"28`0``B<N+C"2<`0``"<.+1"0PB=V!PJ'KV6Z);"1(@]$`B<N)T3'2
M`<@1VHM<)$`QZXML)#@QW3';B>D!P8GP$=/!X`4QTHE$)"B)\(ML)"@/K/@;
MB40D,`ML)#"+1"0@`>D1TXG*B<&)7"1LB50D:,'A'HE4)"B+5"0DB<V+C"2D
M`0``QT0D-``````/K-`"BY0DH`$```G%BT0D0(EL)#B+;"1(@<*AZ]EN@]$`
MB<N)T3'2`<@1VC-L)#B)1"0@B50D)(M4)&`QVXG9BT0D*(N<)*@!```QZ@-4
M)"`33"0DB50D((M4)"R)3"0DB<'!X06)3"0PB=&+;"0PB<*+1"1(#ZS*&XM,
M)"`)U0'IB4PD,(E,)$")\<'A'@^L_@*)S8M\)#`)]8'#H>O9;@'8BUPD.(EL
M)&`QZXML)&@QW8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QL)_HGP`<B)1"0@
MBT0D*(M4)"R+="1@BWPD0,=$)"0`````B<''1"0L`````,=$)$P`````#ZS0
M`L'A'HN4)+`!``")\XG-QT0D/``````)Q8M$)#B!PJ'KV6Z);"1(`=`QZXM4
M)"0QWXN<)+P!``")^0'!BT0D(,'@!8E$)"B+1"0@BWPD*`^LT!N+5"0TB40D
M.`M\)#B)^`'(B40D*(M$)#")P0^LT`+!X1X)P8GPB<^)3"0XBXPDN`$``('!
MW+P;CX/3`#'2`<B+3"1($=H)_2-L)"`QVR'YB<X)[HGQ`<&+1"0H$=.+5"0L
MB4PD,(E<)#2)P<'A!8E,)$")T8ML)$")P@^LRAL)U8GH`T0D,(M4)"0QVXMT
M)$C'1"0T`````,=$)$0`````B40D,(M$)"")P<'A'@^LT`*)S8GYB?H)Q8M$
M)"@)Z2'JB6PD0"'(B<<)UP.T),`!``")^8M\)$P3O"3$`0``QT0D3`````")
M\(G.!=R\&X^)^HG?@](``<:+1"0P$=>+5"0TB70D((E\)"2)Q@^LT!O!Y@6+
M5"0LB<$)\8G(`T0D(#'_B<:+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)$@C
M;"0PB4PD8(M,)$`AT0G-`X0DR`$``(GI!=R\&X\!P8GPP>`%B40D((GP#ZSX
M&XE$)"B+;"0@"VPD*(M4)#3'1"0D`````,=$)#0`````QT0D/`````")Z`'(
M,=N)1"0@BT0D,(G!P>$>#ZS0`HM4)&")S0G%B6PD,`GJB="+5"1((?`AZ@G0
MBU0D1(G!BT0D0`.$)-`!```3E"34`0``!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&)P@^LRAN+3"0XB50D0`M,)$")
MR`-$)"B)\<'A'HE$)"B)\`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1@BW0D
M2(M4)"3'1"1$``````G]`[0DV`$``(M\)"B)Z8ML)"R)\`7<O!N/`<&)^,'@
M!8E$)$"+="1`#ZSO&PG^B?`!R#'_,=N)QHM$)"")P<'A'@^LT`*)S8M4)&`)
MQ8M$)"B);"1`">HAT(M4)#@AZ@G0BU0D-,=$)#0`````B<&+1"0P`X0DX`$`
M`!.4).0!```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPBU0D+`^L^!N)7"0D
MQT0D)`````")1"0P"TPD,(G(`T0D(#';B40D((M$)"B)P0^LT`+!X1X)P8G*
M"<V)3"0PB4PD2(M,)$`A]8M$)#@AT8M4)#S'1"0\``````G-`X0DZ`$``!.4
M).P!``")Z07<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L`````(G!
MP>$%B4PD.(G1BVPD.(G"#ZS*&XGQ"=6+5"1(B>@#1"0HP>$>B<TQVXE$)"B)
M\(MT)$`/K/@""<6+1"0@">J);"0X(="+5"0PB<<AZ@G7`[0D\`$``(GYBWPD
M1!.\)/0!``")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+5"0LB70D0(E\)$2)
MQ@^LT!O!Y@6)P0GQB<@#1"1`,?^)QHM$)""+5"0DQT0D)`````#'1"1$````
M`,=$)#0`````B<$/K-`"P>$>"<&+1"0PB<J)3"1`B4PD2`G-BTPD."-L)"@A
MT8M4)"P)S0.$)/@!``")Z07<O!N/`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D
M,`ML)#")Z`'(,=N)1"0@BT0D*(G!P>$>#ZS0`HM4)$B)S0G%B6PD,`GJB="+
M5"1`(?`AZ@G0BU0D/(G!BT0D.`.$)``"```3E"0$`@``!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0HB5PD+(G!P>$%B4PD.(G1B<(/K,H;B50D2(M,)#@+3"1(
MQT0D+`````"+5"0DQT0D/`````#'1"1$`````(G(`T0D*(GQP>$>B40D*(GP
MBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0(`@``BWPD*(GI
MBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(,?\QVXG&BT0D
M((G!P>$>#ZS0`HG-BU0D2`G%BT0D*(EL)$`)ZB'0BU0D."'J"="+5"0TB<&+
M1"0P`X0D$`(``!.4)!0"```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPB5PD
M)`^L^!N)1"0P"TPD,(M4)"S'1"0D`````,=$)#0`````B<@#1"0@,=N)1"0@
MBT0D*(G!#ZS0`L'A'@G!BT0D.(G*B4PD,(E,)$@)S8M,)$`A]2'1BU0D/,=$
M)#P`````"<T#A"08`@``$Y0D'`(``(GI!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0XB<(/K,H;B?$)U8M4)$B)
MZ`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$)"`)ZHEL)#@AT(M4)#")
MQR'J"=>)^8M\)$0#M"0@`@``$[PD)`(``,=$)#0`````B?")S@7<O!N/B?J)
MWX/2``'&BT0D*!'7BU0D+(ET)$")?"1$QT0D1`````")Q@^LT!O!Y@6+5"0D
MQT0D)`````")P0GQB<@#1"1`,?^)QHM$)"")P0^LT`+!X1X)P8M$)#")RHE,
M)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D*`(``(GI!=R\&X\!P8GPP>`%
MB40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$)""+1"0HB<'!X1X/K-`"
MBU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"=")P8M$)#@#A"0P`@``BU0D/!.4
M)#0"``#'1"0\``````7<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L
M`````(G!P>$%B4PD.(G1B<(/K,H;BTPD.(E4)$@+3"1(BU0D)(G(`T0D*(GQ
MP>$>B40D*(GPBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0X
M`@``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(
M,?\QVXG&BT0D((G!P>$>#ZS0`HG-"<6);"1`QT0D1`````"+5"1(BT0D*`GJ
M(="+5"0X(>H)T(M4)#2)P8M$)#`#A"1``@``$Y0D1`(```7<O!N/@](``<&)
M\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+3"0PQT0D
M+`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)"B)
M3"1@BTPD0"'U(=&+5"0\"<T#A"1(`@``$Y0D3`(``(GI!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0PB5PD-(G!P>$%B4PD.(G1BVPD.(G"B?#'1"0T``````^L
MRAN+3"0PQT0D/``````)U8M4)&`!Z8E,)$B)3"0PB?$/K/@"P>$>BW0D0(G-
M"<6+1"0@">J);"1HB6PD."'0BU0D*(G'(>H)UP.T)%`"``"+5"0TB?F)\`7<
MO!N/`<&+1"0PB<N)Q@^LT!N+5"0DP>8%B40D0(ML)$"+1"0@"?4!ZXG!,?\/
MK-`"P>$>BU0D+(ML)&@)P8M$)"@#A"18`@``$Y0D7`(``(E<)&")WHE,)$`%
MUL%BRH/2`#'-B40D((E4)"2+5"1(B=@QZHG1`TPD(,'@!8E$)"")V(ML)"`/
MK/@;BU0D-(M<)$")1"0H"VPD*(M$)##'1"0D``````'IB4PD((E,)$B)P<'A
M'@^LT`*)S8M4)#P)Q8M$)#@#A"1@`@``$Y0D9`(``(EL)#@%UL%BRH/2`#'K
MBVPD8#'=,=N)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LB?/'1"0L`````(G!P>$%
MB4PD,(G1BVPD,(G"#ZS*&XM,)"@)U8GR`>G!XAZ)U8N4)&@"``")3"1@#ZS[
M`HE,)"B+3"1`"=V!PM;!8LJ)T(EL)$`!R#-L)#B)Z8ML)$B+7"0LBU0D),=$
M)#0`````QT0D)``````QS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/K-D;
MB?.+="1`"<V)P0'KP>$>#ZS0`HG-BY0D<`(``(E<)#`)Q8M$)#B+?"0PB6PD
M.(E<)$B!PM;!8LH!T#'NBVPD8(M4)"PQ]8GIBVPD-`'!B?C!X`6)1"0@BW0D
M(`^L[QN+1"0H"?X!\8MT)#B)3"0@B4PD8(G!P>$>#ZS0`HG-BXPD>`(``(M4
M)"0)Q8M$)$")[XGU@<'6P6+*B7PD.`'(,?TS;"1(B>D!P8M$)"#!X`6)QXM$
M)"`/K-`;B40D*(ML)"B+1"0PBU0D-,=$)"P`````QT0D-``````)_0'IB4PD
M2(E,)"B)P0^LT`*+E"2``@``P>$>B<T)Q8GP@<+6P6+*B6PD0`'0,VPD.(M4
M)"PS;"1@B>D!P8M$)"B)RXG&B<>+1"0XP>8%B70D,(ML)#`/K-<;"?V+?"0@
M`>N+;"0DQT0D)`````")7"0PB5PD8(GZB?Z+?"0T#ZSN`L'B'HG5BY0DB`(`
M``GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`6)
M1"0@BW0D(`^L[QN+1"0H"?X!\8E,)$B)3"0@B<&+5"0LP>$>BWPD.(G-QT0D
M+``````/K-`"BY0DD`(```G%BT0D0(GNB?V!PM;!8LJ)="0X`=`Q]3-L)&"+
M5"0DB>D!P8M$)"")R\'@!8E$)"B+1"0@BVPD*`^LT!N+5"0TQT0D-`````")
M1"1`"VPD0(M$)#`!ZXG!#ZS0`HN4))@"``#!X1Z)7"0HB<V)7"1@"<6)^('"
MUL%BRHEL)$`!T#-L)#B+5"0L,VPD2(GI`<&+1"0HB<:)Q\'F!8ET)#"+;"0P
M#ZS7&PG]BWPD(`'IBVPD)(E,)$B)3"0PB?J)_@^L[@+!XAZ)U8N4)*`"``"+
M1"0X"?6+="1`BWPD-(EL)#C'1"0D`````('"UL%BR@'0,>Z+;"1@BU0D+,=$
M)"P`````,?6+="0PB>F)_0'!B?")]XG+P>`%B40D((M$)"B+="0@#ZSO&XG!
M"?Z+?"0X`?/!X1X/K-`"B<V+E"2H`@``B5PD(`G%BT0D0(E<)&")[HG]@<+6
MP6+*B70D:`'0,?4S;"1(BU0D)(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0
M&XM4)#2)1"0X"VPD.(M$)#`!Z8E,)$")3"0HB<$/K-`"BY0DL`(``,'A'HG-
M"<6)^('"UL%BRHEL)#@!T#'U,VPD8(M4)"S'1"0T`````(GI`<&+1"0HB<N)
MQHG'BT0D:,'F!8ET)#"+;"0P#ZS7&PG]BWPD(`'KBVPD),=$)"0`````B5PD
M,(E<)$B)^HG^BWPD-`^L[@+!XAZ)U8N4)+@"```)]8MT)#B);"1H@<+6P6+*
M`=`Q[HML)$"+5"0L,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO&XM$
M)"@)_HM\)&@!\8E,)"")3"1@B<'!X1X/K-`"B<V+E"3``@``"<6+1"0XB>Z)
M_8'"UL%BRHET)#@!T#'U,VPD2(GI`<&+1"0@B<O!X`6)1"0HBT0D((M4)"2+
M;"0HQT0D+``````/K-`;BU0D-,=$)#0`````B40D0(M$)#`+;"1`B<$!Z\'A
M'@^LT`*+E"3(`@``B<V+C"3,`@``"<6)7"1(B5PD*(GXB6PD0('"UL%BRH/1
M`(G+B=$QT@'($=HS;"0X,=LS;"1@B>D!P8M$)"@1TXM4)"R)QHG'BT0D.,'F
M!8ET)#"+;"0P#ZS7&S'2"?V+?"0@`>F+;"0D$=.)3"0PB4PD8(GZB?Z+?"0T
M#ZSN`L'B'HE<)&2)U8N4)-`"```)]8MT)$");"0X@<+6P6+*`=`Q[HML)$@Q
M]8MT)#")Z8G]`<&)\(GWB<O!X`6)1"0@BW0D((M$)"B+5"0L#ZSO&\=$)"0`
M````QT0D+``````)_HG!BWPD.`'SP>$>#ZS0`HN4)-@"``")S8N,)-P"```)
MQ8M$)$")7"0@B5PD2(GNB?V!PM;!8LJ#T0")RXG1,=(!R!':,?4S;"1@,=N)
M="1@B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML)"@/K-`;,=*)1"0X"VPD
M.(M$)#`!Z1'3BU0D-(E,)"B)3"1`B<&)7"1$P>$>#ZS0`HN4).`"``")S8N,
M).0"```)Q8GXB6PD.('"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)$@QVXGI`<&+
M1"0H$=.+5"0LB<:)Q\'F!8ET)#"+;"0PB=X/K-<;B<LQTHM$)&`)_8M\)"#'
M1"0T``````'KBVPD),=$)"0`````$=:)7"0PB5PD2(ET)$R)^HG^#ZSN`L'B
M'HM\)$")U8N4).@"```)]8MT)#B);"1@@<+6P6+*`=`Q[HM4)"PQ]XMT)#")
M^8M\)#0!P8GPP>`%B?V)]XE$)""+="0@#ZSO&XML)&`)_HGP`<B)1"0@BT0D
M*(G!#ZS0`L'A'HM4)#`)P8M$)#B)SXM,)#2)TXE\)$#!XQZ)SHE<)"@/I-8>
M#ZS*`L'I`HET)"R)[HE,)#2+C"3P`@``B50D,('!UL%BR@'(,?XS="1(B?$!
MP8M$)"#!X`6)QHM$)""+5"0DBUPD*`^LT!O!ZAN)1"0XBWPD.(E4)#P)]XGX
MBWPD5`'(B<&+1"08`TPD$`-$)"`+7"0PQT<$`````,='#`````#'1Q0`````
MQT<<`````(D/QT<D`````(E'"(G8`P0DB4<0BT0D0`-$)`B)1QB)Z`-$)%B)
M1R"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</H,2```)!55U93Z!?7__^!
MP\>-``"#[!R%P`^$G@```(N+'`$``(L)A<F)3"0(#X2*````#[8(A,ET!8#Y
M/75&,?:+?"0(BR^%[70OB50D#(E$)`1FD(/L!%;_="0,5>BRT___@\00A<!U
M!X!\-0`]="R#QP2++X7M==N#Q!R)Z%M>7UW#D(G&@\8!#[8.A,ET!8#Y/77Q
M*<;KIXUV`(GZ*U0D"(M$)`R-;#4!P?H"B1"#Q!R)Z%M>7UW#C78`,>WKN8UT
M)@!75HG&4^A/U___@<(&C0``@^P0B[H<`0``C5PD"&6A%````(E$)`PQP(G:
MB?#H#O___X7`=#.+5"0(BP>-!)"+4`2%THD0=.&0C;0F`````(/`!(M0!(72
MB1!U](G:B?#HV_[__X7`=<V+1"0,93,%%````'4'@\006UY?P^CN'@``C;0F
M`````(V\)P````!55XG%5E.)UNC#U?__@<-SC```@^PX9:$4````B40D*#'`
M,<"`.CT/E,`!QE;H/M'__X/$$(D$)(GHC50D&.AM_O__A<`/A`T!``"#[`R)
MQU#H&M'__X/$$#L$)`^#W@```(M$)!B-#(4`````BX,<`0``B40D!`^V10"$
MP`^$I0$``#P]#X2=`0``B>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#[`R+
M.@'/BTPD#(U$"`)0Z%;1__^#Q!"%P(D'#X1U`0``BU0D!(U-`8L"BU0D&(L4
MD`^V10`\/8@"=".$P'4/ZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`B`)U
M[,8"/3'`C;0F``````^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A10!
M``"#Q"Q;7E]=PXVV`````(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#'`$`
M`(L0B40D!(LZA?\/A,(````QP.L(C;8`````B?B->`&+#+J%R77TC02%#```
M`(N+<!$``(7)=6N)5"0(@^P,QX-P$0```0```%#H9-#__X/$$(7`#X2%````
MC0R]`````(/L!%&+5"00B4PD%%*)1"044.B;T/__BTPD%(M$)!B#Q!")`8M,
M)`R+1"0(QT2X!`````")?"08Z7S^__^0C70F`(/L"%!2Z/;-__^+3"04B40D
M&(/$$(7`B0%T(8T,O0````#KPHUT)@`QP.ER_O__D+@(````,?_I3____[C_
M____Z=O^___HE1P``)"-="8`55>)Q593Z'73__^!PR6*``"![(P```!EH10`
M``")1"1\,<"%[70&@'T``'4CBT0D?&4S!10````/A2<!``"!Q(P```!;7E]=
MPXVT)@````"#[`Q5Z&?.__^)1"00@\00A<!TR8V#D9+__XE$)`2-@Y"2__^)
M1"0(@^P,_W0D#.A\SO__@\00A<`/A+$```"-4!.+?"0$N0(```")UO.F=->+
M?"0(N0,```")UO.F=,B)5"0,@^P,5>ACSO__BU0D'(G&B10DB50D'.A1SO__
MC40&`HD$).CESO__B<986HM4)!2-@Y.2__]255!J_VH!5NA:S___@\0<C40D
M(%!6:@/HNLS__X/$$(/X_W00BT0D+"4`\```/0!```!T/H/L#%;H"<[__X/$
M$(/L#%;H7<W__X/$$.D]____D(UT)@"#[`S_="0,Z#3.__^)+"3HG,[__X/$
M$.G1_O__B?#HG?[__^O%Z"8;``"-M@````!75HG'4^@&TO__@<.VB```@^P,
MB[/\````_S;HT,S__X/$#`4\`0``4%=J`^C_S/__@\00A<!T"%LQP%Y?PV:0
M@^P,_S;HILS__XN`3`$``(/$$"4`\```/0!```!T'X/L#/\VZ(?,__^+@$P!
M``"#Q!`E`/```#T`H```=;J#[`AJ`E?HM\S__X/$$(7`#Y3`6P^VP%Y?PY"-
MM"8`````55>)QU93Z&71__^!PQ6(``"![#`0``!EH10```")A"0@$```,<")
M5"0,:/\/``"-@YF2__^-="0D5E#HP,W__X/$$(7`#XZ-````C6C_BY/\````
M@'PL'`"+$G13B<6)5"0,@^P$56HO5NCAS?__@\00A<"+5"0,=#Z#[`Q2Z,W+
M__]55E=0Z+3,__^#Q""+A"0<$```93,%%````'5#@<0L$```6UY?7<.-M@``
M``"%[76KC70F`(/L#%+HC\O__X/$#/]T)`Q74.A1R___@\00Z[N-="8`BX/\
M````BQ#KUNB9&0``B?:-O"<`````4^AZT/__@<,JAP``@^P4BX/\````_S#H
M1,O__XV3C)3__U*-DZB2____LQ`!``!24.A:S?__@\0H6\.0C70F`%93Z#G0
M__^!P^F&``"#[!"+L_P```#_-N@#R___B00DZ)O___]8_S;H\\K__UJ-DSV4
M__]9:@!24HV3L(W__U*-D\22__]24.A3R___@\0D6U[#C;8`````C;PG````
M`%575E/HU\___X'#AX8``('L'"```&6A%````(F$)`P@```QP.AWR?__C9.D
MDO__@^P(4E"-@]F2__]0:`$0``!J`8UT)"96Z&3,__^#Q!QH`!```(V\)!,0
M``!75N@.S/__@\00A<!X1XG&C4`!@^P,4.BIR___@\00A<")Q703@^P$5E=0
MZ.7*___&1#4``(/$$(N,)`P@``!E,PT4````B>AU#X'$'"```%M>7UW#,>WK
MW^@W&```C;0F`````.D[____C70F`(V\)P````!55U93Z`?/__^!P[>%``"!
M[#P0``"+O"10$```C50D*(NT)%00``!EH10```")A"0L$```,<"-@^62__^)
M?"0,Z*OW__^#[`B)Q6HO5^@.R?__@\00A<!T-XM\)`R-@^Z2__^)^NC6^/__
MB?B+E"0L$```93,5%`````^%H`$``('$/!```%M>7UW#D(UT)@"#[`S_="08
MZ!3*__]:68E$)!R-@_N2__^)1"084%;HW<K__X/$$(7`B<9TG8V#D9+__X`^
M`(E$)!R+@_P```")1"08#X3H````C;0F`````(7M=!6#[`A65>ABR___@\00
MA<`/A*0```"#[`Q6Z*[)__^#Q!"`?`;_+W42C70F`(/H`8!\!O\OQ@0&`'3R
MBTPD%(U$"`$]_P\```^/*/___XV#_9+__X/L!/]T)!!0C8/XD___5E!H`!``
M`&H!C70D2%;HB,K__X/$%(M\)"3_-^B*R/__@\0,!3P!``!05FH#Z-G'__^#
MQ!"%P'4?@^P,_S?H:,C__XN`3`$``(/$$"4`\```/0"```!T4X/L"/]T)!AJ
M`.CER?__@\00A<")Q@^$H?[__X`^``^%'____X7M=!.+?"0<N0(```")[O.F
M=,F-="8`BW0D'+@!````Z3C___^-=@"-O"<`````@^P(:@%6Z$7(__^#Q!"%
MP'6;C8/NDO__B?+H,??__X/L#%;H*,K__X/$$.E,_O__Z/L5``"-="8`C;PG
M`````(M4)`0/M@J)T(3)=!N-=@"#P@&`^2\/M@H/1,*$R77P\\.-M@````#S
MPXVV`````%93Z*G,__^!PUF#``"#[!2+="0@A?9T.`^V%H32=#&(5"0/@^P,
M5N@DR/__C40&_X/$$`^V5"0/.<9R"^L^9I"#Z`$YQG0Y@#@O=/3K)V:0C8.1
MDO__@^P,4.B!R?__@\00@\046U[#D(VT)@````"`."]T,(/H`3G&<O0YQG4E
M@/HO=,N-@_V2__^#[`Q0Z$S)__^#Q!#KR8VT)@````"`."]U!X/H`3G&<O0I
M\(U0`H'Z`!```'<G@\`!:``0``!05HVS<`$``%;HX<7__X/$$(GP@\046U[#
MC;8`````,<#I>____XGVC;PG`````%=64^BXR___@<-H@@``@^PP9:$4````
MB40D+#'`BX-HE/__C70D!(E$)`J+@VR4__^)1"0.BX-PE/__B40D$HN#=)3_
M_XE$)!:+@WB4__^)1"0:BX-\E/__B40D'HN#@)3__XE$)"*+@X24__^)1"0F
M#[>#B)3__V:)1"0JC8/_DO__Z-CT__^-@PB3___HS?3__XV#$)/__^C"]/__
MC8,9D___Z+?T__^-@R"3___HK/3__XV#,)/__^BA]/__C8/EDO__Z);T__^-
M@SR3___HB_3__XV#1I/__^B`]/__C8-0D___Z'7T__^-@^Z2___H:O3__XV#
M6I/__XGRZ)WS__^%P'0-B<*-@T:3___HW/3__XV#:Y/__XGRZ'_S__^%P'0-
MB<*-@WV3___HOO3__XV#B)/__XGRZ&'S__^%P'0UB<*-@^62___HH/3__XV3
MM)/__XV#()/__^B/]/__BT0D+&4S!10```!U48/$,%M>7\.-=@"-@YB3__^)
M\N@;\___A<!U)XUT)!N-NZF3__^Y"@```/.F=;2-5"0EC8,\D___Z$7T___K
MHXUV`(G"C8,\D___Z#/T___KD>@,$P``C;8`````C;\`````4^CJR?__@<.:
M@```@^P89:$4````B40D##'`BX,X`0``@_C_=!J+3"0,93,-%````'4^@\08
M6\.0C;0F`````(U4)`B-@SR3___H@?+__XG",<"%TG02#[82@/HP#Y7!,<"$
MT@^5P"'(B8,X`0``Z[7HBA(``(UV`(V\)P````!3Z&K)__^!PQJ```"#[`CH
M/,7__X/L#%#H$\7__X/$$(7`=`R+`(/$"%O#D(UT)@`QP.ORC;8`````C;\`
M````55=64^@GR?__@</7?P``@^P<9:$4````B40D##'`C50D"(V#MI/__XM\
M)##HW_'__X7`=&N`.`")QG1D@^P(5U#H&L7__X/$$(7`=6"#[`Q7Z'K$__^)
MQ8DT).APQ/__C40%`HD$).@$Q?__B<6-@_N2__^#Q`Q64(V#^)/__U=0:O]J
M`57H=<7__XV#MI/__X/$((GJZ,7R___K$(UV`(V#MI/__XGZZ+/R__^+1"0,
M93,%%````'4(@\0<6UY?7</H>1$``(GVC;PG`````%575E/H5\C__X'#!W\`
M`('L/($``(N$)%"!``"-5"0\C;/&D___QT0D2`````#'1"1L`````(ET)$S'
M1"14`````(E$)!")5"0(9:$4````B80D+($``#'`C8/2D___B40D0(V#D9+_
M_XE$)$2-@WV3__^)1"0$B40D6(V#=I/__XE$)%R-@]>3__^)1"1@C8.3D___
MB40D9(V#WY/__XE$)&B-@^.3__^)1"10C8/EDO__Z(CP__^%P'0)@#@`#X4K
M`@``Z";^__^%P(G%#X1D`@``@^P,5>@CP___C40``8D$).BWP___B40D$(/$
M$(!]``!T+(LT)(V[[)/__Y`/MD4`@^P,@\4!4%=J_VH!5H/&`N@7Q/__@\0@
M@'T``'7>C7PD6(M$)`2+;"0(ZPV#QP2+!X7`#X1K`0``B>KH_.___X7`B<9T
MYH`X`'3AZ/ST__^%P'38@^P,5N@OQ/__@\00A<")Q@^$.@$``&:0B?"+"(/`
M!(V1__[^_O?1(<J!XH"`@(!TZ8G1P>D0]\*`@```#T31C4@"#T3!B=$`T8L,
M)(/8`RGPBSF#P02-E__^_O[WUR'Z@>*`@("`=.F)UXLL),'O$/?"@(````]$
MUXUY`@]%^8G1`-&#WP.#[`PI[XV\.`0$``!7Z+#"__^)1"00B<&-@_&3__]5
M4(V#_9+__XE$)#A0C8/VD___5HG.4&K_:@%1Z!/#__^#Q"AHP`$``%;H!<#_
M_X/$$(/X_W40Z-B___^+`(/X$0^%?PD``(NS_````(/L#/\VZ.W`__^#Q`P%
M/`$``%#_="0(:@/H&<'__X/$$(7`B<4/A"P!``"#[`S_="0,BT0D(/\PC8/4
ME/__4(N#&`$``&H!_S#HZ;___X/$(,=$)`0`````ZVR-="8`,?^-M@````"+
M=+Q`A?9T,(`^`'0KB?"#QP'HB?/__X7`=.6#[`Q6Z+S"__^#Q!"%P'35B<;I
MCO[__XVV`````#'VZ8'^__^0@^P,4(E$)!#H,_S__XM$)!")!"3HA\+__XE$
M)!2#Q!"+C"0L@0``93,-%````(M$)`0/A80)``"!Q#R!``!;7E]=PY"-="8`
MB?`Q_X7`=!V+5"0(@\<!Z/3M__^%P'0%@#@`=2N+1+Q,A<!UXX/L#(VKRY/_
M_VH-Z#/!__^)1"00@\00Z7W]__^-M"8`````@^P,4.@'PO__@\00A<!TQ8G%
MZ3W]__^)]HV\)P````"#[`S_-NB6O___BX!,`0``@\00)0#P```]`$````^%
ML?[__X/L#/\VZ'.___^+@%0!``")1"04Z&3`__^#Q!`Y1"0$#X6+_O__@^P,
M_S;H3;___XN`3`$``(/$$"7_`0``/<`!```/A6C^__^#[`Q7Z(O`__^+5"08
MB40D%(V#P9/__^@8[?__@\00A<`/A%T!``"#[`Q0Z%3!__]>7U"+1"0<_S#H
M!O7__XE$)!B#Q!"%P`^$-P$``(/L#(M\)!17Z)J___^#Q!"#^`-V,HE\)`B-
M=`?\C;O_D___N04```#SIG4;@_@$#X2R!@``BWPD"(!\!_LO#X2C!@``C78`
MZ,OY__^%P'4=@^P(:@#_="04Z*G`__^)1"0@@\00A<`/A=H```"-D[23__^-
MLSV4__^-@SR3__^-NR:4___HK>W__^@XO?__5E"-@QB4____="0H_W0D#%!J
M_VH!_W0D(.@JP/__@\0@B70D"(MT)`3K-I"-="8`Z/.\__^#.!%U/>CYO/__
M@\4!@^P,_W0D%%50_W0D./]T)!Q7:O]J`5;HZK___X/$,(/L"&C``0``5NC9
MO/__@\00@_C_=+F#[`S_="0,Z`6^__^+?"04C8/EDO__B?KH%.W__XD\).BL
M^?__@\00Z83]__^-="8`BT0D$(L`B40D".FZ_O__D&H":O]J[HM\)!Q7Z""]
M__^#Q`QJ!HV$)#0!``")1"004%?HB;W__X/$$("\)"P!````=0Z`O"0M`0``
M0P^$,08``&H`:@!J`/]T)!SHW[S__\>$)(`````!(T5GQX0DA`````````#'
MA"2(````B:O-[\>$)(P`````````QX0DD````/[<NIC'A"24`````````,>$
M))@```!V5#(0QX0DG`````````#'A"2@````\.'2P\>$)*0`````````QX0D
MJ`````````#'A"2L`````````,>$)+``````````QX0DM`````````#'A"3X
M`````````(/$$(U$)'")1"0LC80DJ````(E$)"2-="8`@^P$:`"```#_="00
M_W0D'.B+O/__@\00A<")Q0^.[@$``(NT))@```"+O"2<````B>B9P>`#B6PD
M&(E4)!R+C"2D`````?"#_P"+E"2@````=P0YQG8&@\(!@]$`BWPD'(MT)!B)
MA"28````BX0DZ````,>$))P`````````#ZS^'<'O'0'6$<^%P(FT)*````")
MO"2D````#X1A`0``ND`````IPCG5#T[5`T0D)(/L!%+_="00B==0Z(&\__^+
MA"3X`````?B)A"3X````@\00@_A`#X4E____BT0D+"G]`WPD".C&P?__C;8`
M````@_T_#X[H````@^U`B>B);"0HB?W!Z`:-<`&)1"08P>8&`?Z+?"0LB?:-
MO"<`````BT4`@\5`B80DJ````(M%Q(F$)*P```"+1<B)A"2P````BT7,B80D
MM````(M%T(F$)+@```"+1=2)A"2\````BT78B80DP````(M%W(F$),0```"+
M1>")A"3(````BT7DB80DS````(M%Z(F$)-````"+1>R)A"34````BT7PB80D
MV````(M%](F$)-P```"+1?B)A"3@````BT7\B80DY````(GXZ.;`__\Y]0^%
M3O___XM$)!B)[XML)"C!X`8IQ6I$55?_="0PZ)*Z__^)K"3X````@\00Z0/^
M__^-=@"+?"0(Z>?^__^-M"8`````@^P,_W0D'.BDN___BY0DK````(N$)*@`
M``"+O"2P````BZPDM````(E$)!B)5"0<#ZS0`XE\)"");"0D@^`_C5`!QH0$
MN````("#Q!"#^C@/CW4"``"X.````#'_*=`#5"0D@_@$#X.O`@``A<!T"Z@"
MQ@(`#X5E`P``BWPD$(ML)!2)^`^LZ!B(A"3@````B?@/K.@0BVPD#(B$).$`
M``")^(M\)`B(I"3B````B(0DXP```(GX#ZSH&(B$).0```")^`^LZ!"(A"3E
M````B?B(I"3F````B(0DYP```(M$)"SHN+___XMT)'"+?"1TB?*)\0^L^AB(
MK"3Q````B(PD\@````^VPHB4).\```")\HMT)'@/K/H0BWPD?(B4)/````")
M\HGQB*PD]0```(B,)/8````/K/H8B)0D\P```(GRB[0D@`````^L^A"+O"2$
M````B)0D]````(GRB?&(K"3Y````B(PD^@````^L^AB(E"3W````B?*+M"2(
M````#ZSZ$(N\)(P```"(E"3X````B?*)\8BL)/T```"(C"3^````#ZSZ&(B4
M)/L```")\HNT))`````/K/H0B[PDE````(B4)/P```")\HGQB*PD`0$``(B,
M)`(!``"-C"0#`0``#ZSZ&(E,)!")S8V,)"L!``"(E"3_````B?*-M"3P````
M#ZSZ$(E,)`B-N^R3__^(E"0``0``Z0T```"-M"8`````#[8&@\8!@^P,4%=J
M_VH!58/%`N@PNO__@\0@.6PD"'7?C8,]E/__QH0D*P$```!0C8,)E/___W0D
M%/]T)"C_="0,4&K_:@'_="0@Z/BY__^#Q"#I'_K__XM$)!"+4`2%T@^$4?G_
M_X/L#%*)5"0@Z*2X__^#Q!"#^`,/ACCY__^+5"00C;L$E/__N04```"-=`+\
M\Z8/150D"(E4)`CI%?G__XM,)"2X0`````'1*=!T#3'2Q@01`(/"`3G"<O6+
M1"0LZ+"]__^+?"0DN0X````QP/.KZ7G]__^#[`A0_W0D#(M$)"#_,(V#F)3_
M_^FL]O__C4H$QP(`````QT0"_`````"#X?PIR@'"@^+\@_H$#X(\_?__@^+\
M,<")/`&#P`0YT'+VZ2C]__^`O"0N`0``00^%P?G__X"\)"\!``!##X6S^?__
M@+PD,`$``$@/A:7Y__^`O"0Q`0``10^%E_G__VH":O]JQHMT)!Q6Z'6V__^#
MQ`QJ*8M\)!!75NCEMO__C8,]E/__4(V#"93__U?_="0X_W0D'%!J_VH!_W0D
M,.BAN/__@\0PZ<CX__^)]HV\)P`````Q[6:);`+^Z8_\___HOP0``.L-D)"0
MD)"0D)"0D)"0D%575E/HE[O__X'#1W(``(/L.(N[_````&6A%````(E$)"@Q
MP/\WZ%6V__]=_S>)QNA+MO__#[96:(A0:8U$)"B)1"0<B<*-@R"3___H+^3_
M_X/$$(7`=`F`.#$/A*\"``#H>N___X/L#/\WZ!"V__^-DS>4__]J"VH!4E#H
MO[7__X/$((7`#X3^````BT`,@[MX$0```8LOBT`8B40D"`^.YP```#'VZSV-
MM"8`````BT(,@^P(C58!4(N#=!$``/\TD(E4)!3H%+C__X/$$(7`BXMX$0``
M=6^+5"0$C4(!B=8YP7YB@^P,5>B1M?__:@!6_W0D(%#HE+;__X/$((7`=#V+
M$(LOBT(()0`$(``]``0``'2:B50D!(/L#%7H7;7__VH":@"+5"0<4E#HSK?_
M_XLO@\0@Z7?___^-="8`BXMX$0``BR^-0?\Y\'4]@_D!?CB)Z+X!````BVPD
M".L)C;0F`````(L'@^P,@\8!4.@*M?__6EE54.BQM/__@\00.;-X$0``?]Z+
M+X/L#%7HZ[3__XV3/)3__VH#:@%24.B:M/__@\0@A<")QG0RBT`,@^P,BRC_
M-^C"M/__C9,^E/__@\0,4E50Z(&T__^+1@R#Q!"+,/9&"D`/A6\!``"#[`S_
M-^B5M/__C9-#E/__:@-J`5)0Z$2T__^#Q""%P(G&=#:+5"0,C8/NDO__Z&SB
M__^%P(G%#X0"`0``BT8,@^P,BS#_-^A3M/__@\0,5590Z!BT__^#Q!"#[`S_
M-^@[M/__C9-%E/__@\0,:@%24.@YL___B<98_S?H'[3__XV36I3__X/$#%)6
M4.C>L___6O\WZ`:T__^+5"0<QD!I`(V#Y9+__^CSX?__@\00A<")QHF#?!$`
M`'1$@^P(:,`!``!6Z,:R__^-4`&#Q!"#^@%V"8/X$0^%L@```(M$)!QE,P44
M````#X6<````@\0L6UY?7<.)]HV\)P````"#[`S_LW01``#H4O#__X/$$(7`
MB<:)@WP1``!UGXV#*)7__X/L#%#H1+7__XUT)@"`>`$`#X1,_?__Z4+]__^0
MBX-T$0``@^P,BRB+1@R+,/\WZ$FS__^)ZHGPZ/#F__^#Q!#I\_[__Y"-M"8`
M````@^P,_S?H)K/__UE=5E#HC;3__X/$$.EV_O__Z$`!``!0BX-T$0``5O\P
MC8-,E?__4.C*M/__C78`C;PG`````%=64XM<)!#H8P```(''M&X``(/L#%/H
M1>O__P^V$(/$$(G&A-)T&8GVC;PG`````(/``8#Z+P^V$`]$\(32=?#HV^W_
M_X7;=!B%P'04@#L`=`^-O_&3__^Y!````/.F=`1;7E_#B=A;7E_I(>3__XL\
M),-FD&:09I!FD&:09I"04^B*M___@<,Z;@``@^P(_[,T`0``_W0D'/]T)!S_
M="0<Z,JQ__^#Q!A;PV:09I"055=64^A7M___@<,';@``@^P,BVPD*(VS]/[_
M_^B[L/__C8/P_O__*<;!_@*%]G0E,?^-M@````"#[`15_W0D+/]T)"S_E+OP
M_O__@\<!@\00.?YUXX/$#%M>7UW#C78`\\-FD&:09I!FD&:09I!FD%/HZK;_
M_X'#FFT``(/L".@\L___4X/L".C3MO__@<.#;0``@\0(6\,#`````0`"`"XN
M`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!005)?5$5-
M4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`
M4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"
M04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-9
M4U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S
M)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#,`+64`+2T```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I
M;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN
M("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M
M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*
M>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&
M2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F
M<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U
M;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@
M(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]
M/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R
M.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E
M860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D
M7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I
M;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN
M="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F
M:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL
M96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN
M4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M
M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B
M=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]
M"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O
M<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F
M:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N
M)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E
M>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS
M:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L
M=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI
M.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[\````!T````L<?__#`$``/QT
M__\P`0``#'7__W@-``",>/__1`$``&R@__^(`0``+*'__^P!``"\H?__)`(`
M``RD__^D`@``?*7__UP#```<IO__S`,```RG__]H!```3*?__Y@$``"LI___
MY`0``&RH__]T!0``?*C__X@%``"LJO__A`8``-RJ__^8!@``S*O___P&``"<
MK?__-`<``!RN__]8!P``7*[__X0'```LK___\`<``.R[__^\"P``?+___S`-
M``#KO___P`T``/R____4#0``+,#__P`.``",P/__3`X``)S`__]@#@``%```
M```````!>E(``7P(`1L,!`2(`0``(````!P````8</__T`,````."$8.#$H/
M"W0$>``_&CLJ,B0B$````$````#$<___$`````````!`````5````$!W___?
M)P```$$."(4"00X,AP-$#A"&!$$.%(,%1@Z@!@/()PH.%$'##A!!Q@X,0<<.
M"$'%#@1!"P```&````"8````W)[__[P`````00X(A0)!#@R'`T$.$(8$00X4
M@P5.#C`"00XT00XX1`X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1""VX*
M#A1#PPX00<8.#$''#@A!Q0X$1`LT````_````#B?__^"`````$$."(<"00X,
MA@-##A"#!$X.(`)F"@X00<,.#$'&#@A!QPX$00L``'P````T`0``D)___TL"
M````00X(A0)!#@R'`T,.$(8$00X4@P50#DQ7#E!(#D!9#DQ##E!(#D`"3PY,
M30Y02`Y``G@*#A1!PPX00<8.#$''#@A!Q0X$1PL"7`Y,2PY02`Y`4@Y$00Y(
M20Y,10Y04`Y`8PY(00Y,00Y04`Y`````M````+0!``!@H?__:@$```!!#@B%
M`D$.#(<#0PX0A@1!#A2#!5$.H`%M"@X40<,.$$'&#@Q!QPX(0<4.!$@+0PZL
M`4$.L`%,#J`!6PZL`40.L`%(#J`!<`ZL`4$.L`%F#JP!00ZH`4L.K`%!#K`!
M00ZT`4(.N`%"#KP!00[``4@.I`%%#J@!00ZL`4(.L`%(#J`!6`ZL`4$.L`%(
M#J`!0PZL`4$.L`%(#J`!30ZL`40.L`%0#J`!`&P```!L`@``&*+__Y@`````
M00X(AP)!#@R&`T,.$(,$3@X<2`X@2`X41@X800X<0@X@2`X010K##@Q#Q@X(
M0<<.!$,+0PX<0@X@3@X03PX<0@X@3@X03PX80@X<00X@2`X01L,.#$3&#@A!
MQPX$``"8````W`(``$BB___G`````$$."(4"00X,AP-##A"&!$$.%(,%40[$
M(%@.R"!+#LP@00[0($@.P"!C#L0@00[(($(.S"!!#M`@2`[`($L.S"!!#M`@
M1@[4($$.V"!!#MP@00[@($@.P"!6"@X40<,.$$'&#@Q!QPX(0<4.!$<+2P[,
M($$.T"!(#L0@1`[(($$.S"!!#M`@2`[`(``L````>`,``)RB__\[`````$$.
M"(,"3@X<2`X@3`XD3`XH00XL00XP2`X(0<,.!`!(````J`,``*RB__]3````
M`$$."(8"00X,@P-.#AQ(#B!.#AQ"#B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ!
M#C!(#@Q!PPX(0<8.!```C````/0#``#`HO__N0````!!#@B%`D$.#(<#00X0
MA@1!#A2#!5$.L$!=#KA`00Z\0$$.P$!'#L1`10[(0$(.S$!%#M!`2`ZT0$4.
MN$!(#KQ`00[`0$@.L$!,#KQ`00[`0$@.L$!)#K1`00ZX0$$.O$!!#L!`30ZP
M0%@*#A1!PPX00<8.#$''#@A!Q0X$00L`$````(0$``#PHO__!0````````#X
M````F`0``.RB__\E`@```$$."(4"00X,AP-!#A"&!$$.%(,%40[0(',.V"!$
M#MP@00[@($@.T"!Q"@X40<,.$$'&#@Q!QPX(0<4.!$8+0P[<($0.X"!&#MP@
M00[8($\.W"!!#N`@2`[0('$.V"!!#MP@00[@($@.T"!+#MP@00[@($@.T"!U
M#M0@1`[8($$.W"!'#N`@00[D($4.Z"!"#NP@10[P($@.W"!&#N`@2`[4($8.
MV"!!#MP@0@[@($@.T"!'#MP@0@[@($X.T"!/#M@@1`[<($(.X"!(#M`@`D4.
MV"!"#MP@00[@($@.T"!4#MP@00[@($@.T"`0````E`4``""D__\J````````
M`&````"H!0``/*3__^<`````00X(A@)!#@R#`TX.(%8.+$$.,$P.(&8.+$$.
M,$@.($,*#@Q!PPX(0<8.!$D+7@XL00XP2`X@:@XD00XH00XL1PXP2`X@10H.
M#$'##@A!Q@X$1PLT````#`8``,BD___$`0```$$."(<"00X,A@-!#A"#!$X.
M0`-@`0H.$$'##@Q!Q@X(0<<.!$0+`"````!$!@``8*;__W8`````00X(@P).
M#B!G"@X(0<,.!$D+`"@```!H!@``O*;__S0`````00X(@P).#A!(#AQ!#B!(
M#A!)"@X(0<,.!$8+:````)0&``#0IO__QP````!!#@B%`D$.#(<#00X0A@1!
M#A2#!4X.,&T..$$./$$.0$@.,$<./$$.0&8.-$$..$$./$<.0$$.1$(.2$(.
M3$$.4$X.,&D*#A1!PPX00<8.#$''#@A!Q0X$00L`R`,````'```TI___L0P`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!5$.T(("`L(.W(("00[@@@)8#M""`E<.
MW(("1`[@@@)!#N2"`D(.Z(("0@[L@@)!#O""`DL.T(("?P[<@@)!#N""`D@.
MT(("`GT.W(("2@[@@@)2#N2"`D$.Z(("2P[L@@)'#O""`D,.](("0@[X@@)"
M#OR"`D$.@(,"2`[8@@)%#MR"`D$.X(("2`[0@@)>#MR"`D(.X(("2`[4@@)&
M#MB"`D0.W(("0@[@@@)(#M""`DT.W(("1`[@@@)&#N2"`D<.Z(("2`[L@@)"
M#O""`D@.T(("=`[<@@)!#N""`D@.T(("7`[<@@)!#N""`EP.T(("7@H.%$'#
M#A!!Q@X,0<<."$'%#@1&"V@.W(("2`[@@@),#M""`D\.W(("00[@@@)(#M""
M`E<.W(("0@[@@@).#M""`E,.W(("0@[@@@)7#M""`DT.W(("0@[@@@).#M""
M`E,.W(("00[@@@);#M""`DL.W(("00[@@@)&#MR"`D$.V(("00[<@@)&#N""
M`DP.T(("2P[<@@)%#N""`D@.T(("`D,.V(("0@[<@@)$#N""`DP.T((":P[4
M@@)!#MB"`DH.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$#O""`D@.T(("9`[<
M@@)$#N""`D$.Y(("00[H@@)$#NR"`D0.\(("00[T@@)"#OB"`D(._(("00Z`
M@P)(#M""`D,.V(("10[<@@)!#N""`D@.T(("2`[<@@)$#N""`F$.T(("6P[4
M@@)"#MB"`D(.W(("10[@@@)(#M2"`D(.V(("3`[<@@)!#N""`D@.T(("6@[4
M@@)"#MB"`D(.W(("1`[@@@("K0[0@@):#M2"`D4.V(("1`[<@@)$#N""`D@.
MT(("`IH.U(("00[8@@)$#MR"`D,.X(("6`[0@@(#$0$.U(("00[8@@)!#MR"
M`D0.X(("3P[0@@);#MR"`D0.X(("`D8.T(("`^0!#MR"`D$.X(("00[D@@)"
M#NB"`D(.[(("00[P@@)+#M""`E4.U(("2@[8@@)$#MR"`D0.X(("00[D@@)"
M#NB"`D(.[(("1`[P@@)(#M""`E<.W(("00[@@@),#M""`@)F"@[8@@)!#MR"
M`D0.X(("1@[D@@)+"P)R#M2"`D(.V(("0@[<@@)%#N""`D@.U(("0@[8@@)%
M#MR"`D$.X(("3`[D@@)'#NB"`D0.[(("1`[P@@)!#O2"`D(.^(("0@[\@@)$
M#H"#`D@.T(("````<`$``,P*```HL/__A@,```!!#@B%`D$.#(<#00X0A@1!
M#A2#!4X.3%0.4$8.3$(.4&8.0%4.3$(.4$T.5$(.6$$.7$$.8$@.0'(.2$0.
M3$D.4$P.0%H.3$$.4$<.5$$.6$0.7$$.8$@.0%X.3$$.4$<.5$(.6$4.7$$.
M8$H.0'8.3$0.4$8.3$$.2$$.3$$.4$@.0$T.3$$.4$T.5$(.6$$.7$$.8$@.
M0$P.3$0.4$X.1$$.2$$.3$$.4$L.0$\.3$(.4$T.5$(.6$$.7$$.8$@.0&4.
M3$0.4$@.1$$.2$$.3$$.4$@.0$,.3$(.4$X.1$(.2$$.3$$.4$@.3$(.4$X.
M1$$.2$$.3$$.4$8.3$(.4%L.0$\.2$4.3$$.4$L.0&(*#A1!PPX00<8.#$''
M#@A!Q0X$2@M#"@Y,1@Y02`Y`50Y,00Y020M9#DQ)#E!1#D!0#DQ"#E!&#DQ!
M#DA!#DQ!#E!(#D!+#D1'#DA"#DQ'#E``1````$`,``!$LO__;P````!!#@B'
M`D$.#(8#00X0@P12#AQ!#B!+#A`"00K##@Q!Q@X(0<<.!$$+0\,.#$'&#@A!
MQPX$````1````(@,``",9___/`(```!$#`$`1Q`%`G4`1@\#=7`&$`<"=7P0
M!@)U>!`#`G5T`W<!"L$,`0!!PT'&0<=!Q4,,!`1!"P``$````-`,```CLO__
M!``````````H````Y`P``""R__\K`````$$."(,"3@X01@X41`X81`X<1`X@
M2`X(0<,.!$@````0#0``)++__UT`````00X(A0)!#@R'`T$.$(8$00X4@P5.
M#B!I#B1!#BA$#BQ$#C!-#B!'#A1!PPX00<8.#$''#@A!Q0X$```0````7`T`
M`#BR__\"`````````!@```!P#0``-++__Q0`````00X(@P).#A``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````$!D``,`8```!`````0````$```#+`0``
M`0```!H"```,````G!$```T```!$80``&0```,#-```;````!````!H```#$
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````V00```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````O`\`
M`!$````T#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
ME`X``/___V\"````\/__;\8-``#Z__]O!0``````````````````````````
M``````````````````````````````#(S0````````````#6$0``YA$``/81
M```&$@``%A(``"82```V$@``1A(``%82``!F$@``=A(``(82``"6$@``IA(`
M`+82``#&$@``UA(``.82``#V$@``!A,``!83```F$P``-A,``$83``!6$P``
M9A,``'83``"&$P``EA,``*83``"V$P``QA,``-83``#F$P``]A,```84```6
M%```)A0``#84``!&%```5A0``&84``!V%```AA0``)84``"F%```MA0``,84
M``#6%```YA0``/84```&%0``%A4``"85```V%0``1A4``%85``!F%0``=A4`
M`(85````````````````````````````````````````````````````````
M``````````"@%0````````30``#_____8&0``$=#0SH@*%5B=6YT=2`W+C,N
M,"TQ-W5B=6YT=3$I(#<N,RXP`$=#0SH@*%5B=6YT=2`W+C,N,"TQ-G5B=6YT
M=3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN
M;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M``````````````````````L````!`````@```%0!``!4`0``$P``````````
M`````0`````````3````!P````(```!H`0``:`$``"````````````````0`
M````````(0````<````"````B`$``(@!```D```````````````$````````
M`#0```#V__]O`@```*P!``"L`0``X`````4`````````!`````0````^````
M"P````(```",`@``C`(``&`&```&`````0````0````0````1@````,````"
M````[`@``.P(``#9!``````````````!`````````$X```#___]O`@```,8-
M``#&#0``S`````4``````````@````(```!;````_O__;P(```"4#@``E`X`
M`*`````&`````@````0`````````:@````D````"````-`\``#0/``"(````
M!0`````````$````"````',````)````0@```+P/``"\#P``X`$```4````6
M````!`````@```!\`````0````8```"<$0``G!$``",```````````````0`
M````````=P````$````&````P!$``,`1``#0`P`````````````0````!```
M`((````!````!@```)`5``"0%0``$```````````````"`````@```"+````
M`0````8```"@%0``H!4``*1+`````````````!``````````D0````$````&
M````1&$``$1A```4```````````````$`````````)<````!`````@```%AA
M``!880``/#\`````````````!`````````"?`````0````(```"4H```E*``
M`/0```````````````0`````````K0````$````"````B*$``(BA``",#0``
M```````````$`````````+<````.`````P```,#-``#`O0``!```````````
M````!`````0```##````#P````,```#$S0``Q+T```0```````````````0`
M```$````SP````8````#````R,T``,B]```(`0``!@`````````$````"```
M`(8````!`````P```-#.``#0O@``,`$`````````````!`````0```#8````
M`0````,`````T````,```!````````````````0`````````W@````@````#
M````(-```!#````T$``````````````@`````````.,````!````,```````
M```0P```2````````````````0````$````!`````P``````````````6,``
5`.P```````````````$`````````
